import { ViewManager } from '../e2elib/lib/src/ctl/viewmanager.class';

/**
 * SOP View Manager class (extending e2elib ViewManager). Wrap reusable methods to ease scripting (e.g no need explicit open and close viewmanager).
 */
export class ViewManagerSOP extends ViewManager {
  /**
   * Open view manager. Select view from list to redefine and store in model. Closes view manager once done.
   *
   * @param viewName View name to redefine.
   */
  public static async redefineViewStoredWithModelSOP(viewName: string): Promise<void> {
    await ViewManager.openViewManager();
    await ViewManager.redefineViewStoredWithModel(viewName);
    await ViewManager.closeViewManager();
  }

  /**
   * Open view manager. Remove view stored in model and revert to use view from library. Closes view manager once done.
   *
   * @param viewName View name to revert to library.
   */
  public static async resetToViewStoredInLibrarySOP(viewName: string): Promise<void> {
    await ViewManager.openViewManager();
    await ViewManager.resetToViewStoredInLibrary(viewName);
    await ViewManager.closeViewManager();
  }
}

// Step description to re-use in spec file to prevent scriptor re-write each time
const stepViewManager = {
  redefineViewStoredWithModel: (viewName: string): string => `Open Configure > Configure Views. In dialog, select view "${viewName}" and click menu "Redefine View Stored With Model". Close dialog once done.`,
  resetToViewStoredInLibrary: (viewName: string): string => `Open Configure > Configure Views. In dialog, select view "${viewName}" and click menu "Reset to View Stored With Library". Close dialog once done.`,
};

export { stepViewManager as StepViewManager };
